---
title: <span class="badge object-type-scalar"></span> Kilobars
---
# <span class="badge object-type-scalar"></span> Kilobars

Pressure: Kilobars

## Definition

```python
# Pressure: Kilobars
Kilobars: typing.Literal["pressurekbar"] = "pressurekbar"
```
